@@ -424,8 +424,8 @@ postgresqlFetch <- function(res, n=0, ...) {
     ## create running row index as of previous fetch (if any)
     cnt <- dbGetRowCount(res)
     nrec <- length(rel[[1]])
-    indx <- seq(from = cnt - nrec + 1, length = nrec)
-    attr(rel, "row.names") <- as.integer(indx)
+    indx <- seq.int(from = cnt - nrec + 1, length.out = nrec)
+    attr(rel, "row.names") <- indx
     if(usingR())
         class(rel) <- "data.frame"
     else
